@@ -6,7 +6,7 @@ import os
 import json
 import csv
 import pickle
-from dsFramework.base.common import functions
+from dsframework.base.common import functions
 
 class ZIDS_SharedArtifacts():
 
